@@ -369,6 +369,34 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetAccount(self, request):
+        """获取账户信息
+
+        :param request: Request instance for GetAccount.
+        :type request: :class:`tencentcloud.scf.v20180416.models.GetAccountRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.GetAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetAccount", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetAccountResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetAlias(self, request):
         """获取别名的详细信息，包括名称、描述、版本、路由信息等。
 
@@ -621,6 +649,34 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListAsyncEvents(self, request):
+        """拉取函数异步事件列表
+
+        :param request: Request instance for ListAsyncEvents.
+        :type request: :class:`tencentcloud.scf.v20180416.models.ListAsyncEventsRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.ListAsyncEventsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListAsyncEvents", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListAsyncEventsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListFunctions(self, request):
         """该接口根据传入的查询参数返回相关函数信息。
 
@@ -929,6 +985,34 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def TerminateAsyncEvent(self, request):
+        """终止正在运行中的函数异步事件
+
+        :param request: Request instance for TerminateAsyncEvent.
+        :type request: :class:`tencentcloud.scf.v20180416.models.TerminateAsyncEventRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.TerminateAsyncEventResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("TerminateAsyncEvent", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.TerminateAsyncEventResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateAlias(self, request):
         """更新别名的配置
 
